netapp_ontap.models.switch_monitoring API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.switch_monitoring`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SwitchMonitoringSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SwitchMonitoring object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET POST PATCH`

    Enable Health Monitoring.

  `monitored: bool GET`

    Is Monitored.

  `reason: str GET`

    Reason For Not Monitoring.

    Valid choices:

    - none
    - unsupported_model
    - user_deleted
    - bad_ip_address
    - invalid_snmp_settings
    - bad_model
    - invalid_software_version
    - user_disabled
    - unknown